pub struct SnippetData {
pub descriptions: Vec<String>,
pub commands: Vec<String>,
pub tags: Vec<Vec<String>>,
pub folders: Vec<Vec<String>>,
pub favorites: Vec<bool>,
}Expand description
Aggregated data for all snippets passed to the TUI selector.
Contains parallel vectors of snippet metadata where index i corresponds
to the same snippet across all fields.
Fields
descriptions: Vec<String>commands: Vec<String>folders: Vec<Vec<String>>favorites: Vec<bool>Auto Trait Implementations
impl Freeze for SnippetData
impl RefUnwindSafe for SnippetData
impl Send for SnippetData
impl Sync for SnippetData
impl Unpin for SnippetData
impl UnsafeUnpin for SnippetData
impl UnwindSafe for SnippetData