pub enum SnippetSelection {
Selected(usize, Option<String>),
Delete(usize),
}Expand description
Action returned by the snippet selector after the user leaves the TUI.
Variants
Selected(usize, Option<String>)
Select a snippet for the command-specific action.
Delete(usize)
Delete a snippet after the user confirmed the delete dialog.